package com.kakao.sdk.sample.kakaotalk;

import android.content.DialogInterface;
import android.content.DialogInterface.OnClickListener;
import android.widget.Toast;

import com.kakao.auth.ErrorResult;
import com.kakao.friends.response.model.FriendInfo;
import com.kakao.kakaotalk.KakaoTalkService;
import com.kakao.kakaotalk.callback.TalkResponseCallback;
import com.kakao.sdk.sample.common.log.Logger;
import com.kakao.sdk.sample.common.widget.KakaoToast;
import com.kakao.sdk.sample.friends.FriendsMainActivity;

/**
 * @author leo.shin
 */
public class KakaoTalkFriendListActivity extends FriendsMainActivity {
    @Override
    public void onItemSelected(final int position, final FriendInfo friendInfo) {
        if (!friendInfo.isAllowedMsg()) {
            return;
        }

        TalkMessageHelper.showSendMessageDialog(this, new OnClickListener() {
            @Override
            public void onClick(DialogInterface dialog, int which) {
                requestSendMessage(friendInfo);
            }
        });
    }

    private void requestSendMessage(FriendInfo friendInfo) {
        KakaoTalkMessageBuilder builder = new KakaoTalkMessageBuilder();
        builder.addParam("username", "Your name is " + friendInfo.getProfileNickname());
        builder.addParam("labelMsg", "Hi " + friendInfo.getProfileNickname() + ". this is test messagae");
        builder.addParam("linkMsg", "Go to website");
        KakaoTalkService.requestSendMessage(new TalkResponseCallback<Boolean>() {
            @Override
            public void onSuccess(Boolean result) {
                Logger.d("++ send message result : " + result);
                KakaoToast.makeToast(self, "Send message success", Toast.LENGTH_LONG).show();
            }

            @Override
            public void onNotKakaoTalkUser() {
                KakaoToast.makeToast(self, "not a KakaoTalk user", Toast.LENGTH_SHORT).show();
            }

            @Override
            public void onFailure(ErrorResult errorResult) {
                KakaoToast.makeToast(self, "failure : " + errorResult, Toast.LENGTH_LONG).show();
            }

            @Override
            public void onSessionClosed(ErrorResult errorResult) {
                redirectLoginActivity();
            }

            @Override
            public void onNotSignedUp() {
                redirectSignupActivity();
            }

            @Override
            public void onDidStart() {
                showWaitingDialog();
            }

            @Override
            public void onDidEnd() {
                cancelWaitingDialog();
            }
        }, friendInfo, TalkMessageHelper.getSampleTempleteId(), builder.build());
    }

}
